package com.benyun.project.third.byKingdeeConfig.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.benyun.project.third.byKingdeeConfig.mapper.ByKingdeeConfigMapper;
import com.benyun.project.third.byKingdeeConfig.domain.ByKingdeeConfig;
import com.benyun.project.third.byKingdeeConfig.service.IByKingdeeConfigService;
import com.benyun.common.utils.text.Convert;

/**
 * 系统账户配置信息Service业务层处理
 *
 * @author benyun
 * @date 2024-01-10
 */
@Service
public class ByKingdeeConfigServiceImpl implements IByKingdeeConfigService
{
    @Autowired
    private ByKingdeeConfigMapper byKingdeeConfigMapper;

    /**
     * 查询系统账户配置信息
     *
     * @param id 系统账户配置信息主键
     * @return 系统账户配置信息
     */
    @Override
    public ByKingdeeConfig selectByKingdeeConfigById(Long id)
    {
        return byKingdeeConfigMapper.selectByKingdeeConfigById(id);
    }

    /**
     * 查询系统账户配置信息列表
     *
     * @param byKingdeeConfig 系统账户配置信息
     * @return 系统账户配置信息
     */
    @Override
    public List<ByKingdeeConfig> selectByKingdeeConfigList(ByKingdeeConfig byKingdeeConfig)
    {
        return byKingdeeConfigMapper.selectByKingdeeConfigList(byKingdeeConfig);
    }

    /**
     * 新增系统账户配置信息
     *
     * @param byKingdeeConfig 系统账户配置信息
     * @return 结果
     */
    @Override
    public int insertByKingdeeConfig(ByKingdeeConfig byKingdeeConfig)
    {
        return byKingdeeConfigMapper.insertByKingdeeConfig(byKingdeeConfig);
    }

    /**
     * 修改系统账户配置信息
     *
     * @param byKingdeeConfig 系统账户配置信息
     * @return 结果
     */
    @Override
    public int updateByKingdeeConfig(ByKingdeeConfig byKingdeeConfig)
    {
        return byKingdeeConfigMapper.updateByKingdeeConfig(byKingdeeConfig);
    }

    /**
     * 批量删除系统账户配置信息
     *
     * @param ids 需要删除的系统账户配置信息主键
     * @return 结果
     */
    @Override
    public int deleteByKingdeeConfigByIds(String ids)
    {
        return byKingdeeConfigMapper.deleteByKingdeeConfigByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除系统账户配置信息信息
     *
     * @param id 系统账户配置信息主键
     * @return 结果
     */
    @Override
    public int deleteByKingdeeConfigById(Long id)
    {
        return byKingdeeConfigMapper.deleteByKingdeeConfigById(id);
    }
}
